@@ -1,4 +1,4 @@
-package App::sshca v0.0.4;
+package App::sshca v0.0.5;
 
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ sshca - A minimal SSH Certificate Authority
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -135,6 +135,32 @@ Planned.
 
 Planned.
 
+=head2 list
+
+Lists certificates.
+
+Available options:
+
+=over 8
+
+=item * C<--expiry=YYYY-MM-DDThh:mm:ss>
+
+Exclude certs expiring after C<YYYY-MM-DDThh:mm:ss> (ISO 8601 date format).
+
+=back
+
+=head2 cleanup
+
+Deletes expired certificates.
+
+Available options:
+
+=over 8
+
+=item * C<--dry-run>
+
+=back
+
 =head1 GLOBAL OPTIONS
 
 These options can be specified before commands and are accepted with all commands:
